record.MinidomRecord

|  | ## Cheshire3 Object Model: Class MinidomRecord

Module record :: Class MinidomRecord

## Class MinidomRecord
source code

Object Tree:

    baseObjects.Record --+
                         |
                 DomRecord --+
                             |
                            MinidomRecord

Instance Methods

get_xml(self) Return the XML for the record as a serialised string.
_walkTop(self, node)
_walk(self, node)
process_xpath(self, tuple) Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings.
Inherited from `DomRecord`: `__init__`, `get_dom`, `get_sax`

Class Variables

useNamespace |
Inherited from `DomRecord`: `context`, `size` Inherited from `baseObjects.Record`: `baseUri`, `dom`, `elementHash`, `history`, `parent`, `processHistory`, `recordStore`, `resultSetItem`, `rights`, `sax`, `schema`, `schemaType`, `status`, `xml`

Method Details

### get_xml(self) | source code
Return the XML for the record as a serialised string. Overrides: baseObjects.Record.get_xml (inherited documentation)

### _walkTop(self, node) | source code

### _walk(self, node) | source code
Overrides: DomRecord._walk

### process_xpath(self, tuple) | source code
Process the given xpath (either string or compiled), perhaps with some supplied namespace mappings. Overrides: baseObjects.Record.process_xpath (inherited documentation)

Class Variable Details

    ### useNamespace Value:
        1